@@ -1,5 +1,5 @@
-#  tests for pygeos-0.7-py38hc4a24cd_0 (this is a generated file);
-print('===== testing package: pygeos-0.7-py38hc4a24cd_0 =====');
+#  tests for pygeos-0.7.1-py38hc4a24cd_0 (this is a generated file);
+print('===== testing package: pygeos-0.7.1-py38hc4a24cd_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import numpy as np
@@ -12,7 +12,7 @@ area(intersection(polygons_x[:, np.newaxis], polygons_y[np.newaxis, :]))
 
 #  --- run_test.py (end) ---
 
-print('===== pygeos-0.7-py38hc4a24cd_0 OK =====');
+print('===== pygeos-0.7.1-py38hc4a24cd_0 OK =====');
 print("import: 'pygeos'")
 import pygeos
 
